@@ -130,7 +130,7 @@ class TradeItemImportParser:
         parsed_data = csv.DictReader(file_stream)
         """
         -- Field Values
-            0 = Item 
+            0 = Item
             1 =,, (The Header in the file is Empty but it is the UOM for Level 1.)
             2 = GTIN,
             3 = Level2 UOM,
@@ -270,11 +270,10 @@ class TradeItemImportParser:
                 regulated_product_name=product_name,
                 NDC=ndc,
                 NDC_pattern=self.get_ndc_pattern(ndc)
-
             )
 
         # Create the pallet_pack_count TradeItem Field
-        TradeItemField.objects.get_or_create(
+        TradeItemField.objects.create(
             trade_item=trade_item,
             name='pallet_pack_count',
             value=pallet_pack_count
@@ -373,13 +372,13 @@ class TradeItemImportParser:
         template = self.verify_request_template()
 
         try:
-            pool = Pool.objects.create(
+            pool = Pool.objects.get_or_create(
                 readable_name='%s | %s | %s' % (
                     trade_item.regulated_product_name, material_number,
                     trade_item.GTIN14),
                 machine_name=trade_item.GTIN14,
                 request_threshold=self.threshold
-            )
+            )[0]
             self.info_func('Creating a List Based Region in Pool {0} for {1}'.format(pool.readable_name, trade_item.GTIN14))
             region = ListBasedRegion(
                 readable_name=pool.readable_name,
@@ -397,7 +396,9 @@ class TradeItemImportParser:
             region.save()
             self.assign_response_rule(pool)
             self.create_processing_parameters(region)
-        except IntegrityError:
+        except IntegrityError as ie:
+            self.info_func('Handling integrity exception...')
+            self.info_func(str(ie))
             self.info_func('Duplicate number range %s | %s being skipped' %
                            (trade_item.regulated_product_name, material_number))
 
